You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tapestry.apache.org by hl...@apache.org on 2008/05/20 20:52:29 UTC

svn commit: r658390 [24/32] - in /tapestry/tapestry5/branches/hlship-20080520: ./ quickstart/src/main/resources/META-INF/ quickstart/src/main/resources/archetype-resources/src/main/java/pages/ quickstart/src/main/resources/archetype-resources/src/main/...

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateEntityValueEncoder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateEntityValueEncoder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateEntityValueEncoder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateEntityValueEncoder.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
-import org.apache.tapestry.ValueEncoder;
-import org.apache.tapestry.ioc.internal.util.Defense;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.services.PropertyAccess;
-import org.apache.tapestry.ioc.services.PropertyAdapter;
-import org.apache.tapestry.ioc.services.TypeCoercer;
+import org.apache.tapestry5.ValueEncoder;
+import org.apache.tapestry5.ioc.internal.util.Defense;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.services.PropertyAccess;
+import org.apache.tapestry5.ioc.services.PropertyAdapter;
+import org.apache.tapestry5.ioc.services.TypeCoercer;
 import org.hibernate.Session;
 import org.hibernate.mapping.PersistentClass;
 import org.hibernate.mapping.Property;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateMessages.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateMessages.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateMessages.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateMessages.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
-import org.apache.tapestry.ioc.Messages;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.internal.util.MessagesImpl;
+import org.apache.tapestry5.ioc.Messages;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.internal.util.MessagesImpl;
 
 import java.util.Collection;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateSessionManagerImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateSessionManagerImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateSessionManagerImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateSessionManagerImpl.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
-import org.apache.tapestry.hibernate.HibernateSessionManager;
-import org.apache.tapestry.hibernate.HibernateSessionSource;
-import org.apache.tapestry.ioc.services.ThreadCleanupListener;
+import org.apache.tapestry5.hibernate.HibernateSessionManager;
+import org.apache.tapestry5.hibernate.HibernateSessionSource;
+import org.apache.tapestry5.ioc.services.ThreadCleanupListener;
 import org.hibernate.Session;
 import org.hibernate.Transaction;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateSessionSourceImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateSessionSourceImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateSessionSourceImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateSessionSourceImpl.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
-import org.apache.tapestry.hibernate.HibernateConfigurer;
-import org.apache.tapestry.hibernate.HibernateSessionSource;
-import org.apache.tapestry.ioc.services.RegistryShutdownListener;
+import org.apache.tapestry5.hibernate.HibernateConfigurer;
+import org.apache.tapestry5.hibernate.HibernateSessionSource;
+import org.apache.tapestry5.ioc.services.RegistryShutdownListener;
 import org.hibernate.Session;
 import org.hibernate.SessionFactory;
 import org.hibernate.cfg.AnnotationConfiguration;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateTransactionDecoratorImpl.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateTransactionDecoratorImpl.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateTransactionDecoratorImpl.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/HibernateTransactionDecoratorImpl.java Tue May 20 11:51:35 2008
@@ -12,16 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
-import org.apache.tapestry.hibernate.HibernateSessionManager;
-import org.apache.tapestry.hibernate.HibernateTransactionDecorator;
-import org.apache.tapestry.hibernate.annotations.CommitAfter;
-import org.apache.tapestry.ioc.Invocation;
-import org.apache.tapestry.ioc.MethodAdvice;
-import org.apache.tapestry.ioc.internal.util.Defense;
-import org.apache.tapestry.ioc.services.AspectDecorator;
-import org.apache.tapestry.ioc.services.AspectInterceptorBuilder;
+import org.apache.tapestry5.hibernate.HibernateSessionManager;
+import org.apache.tapestry5.hibernate.HibernateTransactionDecorator;
+import org.apache.tapestry5.hibernate.annotations.CommitAfter;
+import org.apache.tapestry5.ioc.Invocation;
+import org.apache.tapestry5.ioc.MethodAdvice;
+import org.apache.tapestry5.ioc.internal.util.Defense;
+import org.apache.tapestry5.ioc.services.AspectDecorator;
+import org.apache.tapestry5.ioc.services.AspectInterceptorBuilder;
 
 import java.lang.reflect.Method;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/ImmutableConfiguration.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/ImmutableConfiguration.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/ImmutableConfiguration.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/ImmutableConfiguration.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
 import org.dom4j.Document;
 import org.hibernate.HibernateException;
@@ -494,5 +494,5 @@
     public String toString()
     {
         return "ImmutableConfiguration[" + config + "]";
-	}
+    }
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/PackageNameHibernateConfigurer.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/PackageNameHibernateConfigurer.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/PackageNameHibernateConfigurer.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/java/org/apache/tapestry5/internal/hibernate/PackageNameHibernateConfigurer.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
-import org.apache.tapestry.hibernate.HibernateConfigurer;
-import org.apache.tapestry.hibernate.HibernateEntityPackageManager;
-import org.apache.tapestry.ioc.internal.util.Defense;
-import org.apache.tapestry.ioc.services.ClassNameLocator;
+import org.apache.tapestry5.hibernate.HibernateConfigurer;
+import org.apache.tapestry5.hibernate.HibernateEntityPackageManager;
+import org.apache.tapestry5.ioc.internal.util.Defense;
+import org.apache.tapestry5.ioc.services.ClassNameLocator;
 import org.hibernate.cfg.AnnotationConfiguration;
 import org.hibernate.cfg.Configuration;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/resources/org/apache/tapestry5/internal/hibernate/HibernateStrings.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/resources/org/apache/tapestry5/internal/hibernate/HibernateStrings.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/resources/org/apache/tapestry5/internal/hibernate/HibernateStrings.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/main/resources/org/apache/tapestry5/internal/hibernate/HibernateStrings.properties Tue May 20 11:51:35 2008
@@ -17,4 +17,4 @@
 configuration-immutable=The Hibernate configuration is now immutable since the SessionFactory has already been created.
 bad-entity-id-type=Failed to load the entity id class while loading a persisted entity. entity: %s, id class: %s, id: %s
 entity-not-attached=Failed persisting an entity in the session. Only entities attached to a Hibernate Session can be persisted. entity: %s
-commit-transaction-interceptor=<Hibernate Transaction interceptor for %s(%s)>
\ No newline at end of file
+commit-transaction-interceptor=<Hibernate Transaction interceptor for %s(%s)>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/site/apt/userguide.apt
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/site/apt/userguide.apt?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/site/apt/userguide.apt (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/site/apt/userguide.apt Tue May 20 11:51:35 2008
@@ -94,7 +94,7 @@
   onSuccess() has the @CommitAfter annotation.
 
   Behind the scenes, the @CommitAfter annotation causes the
-  {{{../apidocs/org/apache/tapestry/hibernate/HibernateSessionManager.html}HibernateSessionManager}}'s commit() method to be
+  {{{../apidocs/org/apache/tapestry5/hibernate/HibernateSessionManager.html}HibernateSessionManager}}'s commit() method to be
   executed before the method returns.
 
   The transaction will be committed when the method completes normally.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/conf/testng.xml
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/conf/testng.xml?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/conf/testng.xml (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/conf/testng.xml Tue May 20 11:51:35 2008
@@ -16,15 +16,15 @@
 -->
 
 <suite name="Tapestry Hibernate" parallel="false" thread-count="10" annotations="1.5" verbose="2">
-  <parameter name="tapestry.integration-webapp" value="src/test/webapp"/>
-  <test name="Tapestry Hibernate Internal APIs">
-    <packages>
-      <package name="org.apache.tapestry.internal.hibernate"/>
-    </packages>
-  </test>
-  <test name="Tapestry Hibernate Integration Tests">
-    <packages>
-      <package name="org.apache.tapestry.hibernate.integration"/>
-    </packages>
-  </test>  
+    <parameter name="tapestry.integration-webapp" value="src/test/webapp"/>
+    <test name="Tapestry Hibernate Internal APIs">
+        <packages>
+            <package name="org.apache.tapestry5.internal.hibernate"/>
+        </packages>
+    </test>
+    <test name="Tapestry Hibernate Integration Tests">
+        <packages>
+            <package name="org.apache.tapestry5.hibernate.integration"/>
+        </packages>
+    </test>
 </suite>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/hibernate/integration/TapestryHibernateIntegrationTests.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/hibernate/integration/TapestryHibernateIntegrationTests.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/hibernate/integration/TapestryHibernateIntegrationTests.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/hibernate/integration/TapestryHibernateIntegrationTests.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.hibernate.integration;
+package org.apache.tapestry5.hibernate.integration;
 
-import org.apache.tapestry.test.AbstractIntegrationTestSuite;
+import org.apache.tapestry5.test.AbstractIntegrationTestSuite;
 import org.testng.annotations.Test;
 
 @Test(sequential = true, groups = "integration")

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/DefaultHibernateConfigurerFilterTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/DefaultHibernateConfigurerFilterTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/DefaultHibernateConfigurerFilterTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/DefaultHibernateConfigurerFilterTest.java Tue May 20 11:51:35 2008
@@ -12,24 +12,23 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
 import static org.easymock.EasyMock.expect;
-import static org.easymock.classextension.EasyMock.createMock;
-import static org.easymock.classextension.EasyMock.replay;
-import static org.easymock.classextension.EasyMock.verify;
-
+import static org.easymock.classextension.EasyMock.*;
 import org.hibernate.cfg.Configuration;
 import org.testng.annotations.Test;
 
 @Test
-public class DefaultHibernateConfigurerFilterTest {
-	public void testConfigure() throws Exception {
-		Configuration config = createMock(Configuration.class);
-		expect(config.configure()).andReturn(config);
-		
-		replay(config);
-		new DefaultHibernateConfigurer().configure(config);
-		verify(config);
-	}
+public class DefaultHibernateConfigurerFilterTest
+{
+    public void testConfigure() throws Exception
+    {
+        Configuration config = createMock(Configuration.class);
+        expect(config.configure()).andReturn(config);
+
+        replay(config);
+        new DefaultHibernateConfigurer().configure(config);
+        verify(config);
+    }
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/EntityPersistentFieldStrategyTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/EntityPersistentFieldStrategyTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/EntityPersistentFieldStrategyTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/EntityPersistentFieldStrategyTest.java Tue May 20 11:51:35 2008
@@ -12,25 +12,31 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
-import org.apache.tapestry.test.TapestryTestCase;
+import org.apache.tapestry5.test.TapestryTestCase;
 import org.hibernate.HibernateException;
 import org.hibernate.Session;
 import org.testng.annotations.Test;
 
 @Test
-public class EntityPersistentFieldStrategyTest extends TapestryTestCase {
-	public void not_an_entity() {
-		Session session = newMock(Session.class);
-		EntityPersistentFieldStrategy strategy = new EntityPersistentFieldStrategy(session, null, null);
-		
-		expect(session.getEntityName("foo")).andThrow(new HibernateException("error"));
-		replay();
-		try {
-			strategy.postChange(null, null, null, "foo");
-			fail("did not throw");
-		} catch (IllegalArgumentException e) { }
-		verify();		
-	}
+public class EntityPersistentFieldStrategyTest extends TapestryTestCase
+{
+    public void not_an_entity()
+    {
+        Session session = newMock(Session.class);
+        EntityPersistentFieldStrategy strategy = new EntityPersistentFieldStrategy(session, null, null);
+
+        expect(session.getEntityName("foo")).andThrow(new HibernateException("error"));
+        replay();
+        try
+        {
+            strategy.postChange(null, null, null, "foo");
+            fail("did not throw");
+        }
+        catch (IllegalArgumentException e)
+        {
+        }
+        verify();
+    }
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/HibernateEntityValueEncoderTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/HibernateEntityValueEncoderTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/HibernateEntityValueEncoderTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/HibernateEntityValueEncoderTest.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
-import org.apache.tapestry.ioc.Registry;
-import org.apache.tapestry.ioc.services.PropertyAccess;
-import org.apache.tapestry.ioc.services.TypeCoercer;
-import org.apache.tapestry.ioc.test.IOCTestCase;
+import org.apache.tapestry5.ioc.Registry;
+import org.apache.tapestry5.ioc.services.PropertyAccess;
+import org.apache.tapestry5.ioc.services.TypeCoercer;
+import org.apache.tapestry5.ioc.test.IOCTestCase;
 import org.hibernate.Session;
 import org.hibernate.mapping.Property;
 import org.hibernate.mapping.RootClass;
@@ -76,7 +76,7 @@
         }
         catch (IllegalStateException ex)
         {
-            assertMessageContains(ex, "Entity org.apache.tapestry.internal.hibernate.SampleEntity",
+            assertMessageContains(ex, "Entity org.apache.tapestry5.internal.hibernate.SampleEntity",
                                   "has an id property of null");
         }
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/HibernateSessionSourceImplTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/HibernateSessionSourceImplTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/HibernateSessionSourceImplTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/HibernateSessionSourceImplTest.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
-import org.apache.tapestry.hibernate.HibernateConfigurer;
-import org.apache.tapestry.hibernate.HibernateEntityPackageManager;
-import org.apache.tapestry.hibernate.HibernateSessionSource;
-import org.apache.tapestry.ioc.internal.services.ClassNameLocatorImpl;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import org.apache.tapestry.test.TapestryTestCase;
+import org.apache.tapestry5.hibernate.HibernateConfigurer;
+import org.apache.tapestry5.hibernate.HibernateEntityPackageManager;
+import org.apache.tapestry5.hibernate.HibernateSessionSource;
+import org.apache.tapestry5.ioc.internal.services.ClassNameLocatorImpl;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.test.TapestryTestCase;
 import org.example.app0.entities.User;
 import org.hibernate.Session;
 import org.hibernate.cfg.Configuration;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/HibernateTransactionDecoratorImplTest.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/HibernateTransactionDecoratorImplTest.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/HibernateTransactionDecoratorImplTest.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/HibernateTransactionDecoratorImplTest.java Tue May 20 11:51:35 2008
@@ -12,15 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
-import org.apache.tapestry.hibernate.HibernateSessionManager;
-import org.apache.tapestry.hibernate.HibernateTransactionDecorator;
-import org.apache.tapestry.hibernate.annotations.CommitAfter;
-import org.apache.tapestry.ioc.IOCUtilities;
-import org.apache.tapestry.ioc.Registry;
-import org.apache.tapestry.ioc.services.AspectDecorator;
-import org.apache.tapestry.test.TapestryTestCase;
+import org.apache.tapestry5.hibernate.HibernateSessionManager;
+import org.apache.tapestry5.hibernate.HibernateTransactionDecorator;
+import org.apache.tapestry5.hibernate.annotations.CommitAfter;
+import org.apache.tapestry5.ioc.IOCUtilities;
+import org.apache.tapestry5.ioc.Registry;
+import org.apache.tapestry5.ioc.services.AspectDecorator;
+import org.apache.tapestry5.test.TapestryTestCase;
 import org.testng.annotations.AfterClass;
 import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/SampleEntity.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/SampleEntity.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/CachedForm.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/CachedForm.java Tue May 20 11:51:35 2008
@@ -14,10 +14,10 @@
 
 package org.example.app0.pages;
 
-import org.apache.tapestry.annotation.Cached;
-import org.apache.tapestry.annotation.Property;
-import org.apache.tapestry.hibernate.HibernateSessionManager;
-import org.apache.tapestry.ioc.annotation.Inject;
+import org.apache.tapestry5.annotations.Cached;
+import org.apache.tapestry5.annotations.Property;
+import org.apache.tapestry5.hibernate.HibernateSessionManager;
+import org.apache.tapestry5.ioc.annotations.Inject;
 import org.example.app0.entities.User;
 import org.hibernate.Session;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/CommitAfterDemo.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/CommitAfterDemo.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/CommitAfterDemo.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/CommitAfterDemo.java Tue May 20 11:51:35 2008
@@ -1,6 +1,6 @@
 package org.example.app0.pages;
 
-import org.apache.tapestry.hibernate.annotations.CommitAfter;
+import org.apache.tapestry5.hibernate.annotations.CommitAfter;
 import org.example.app0.entities.User;
 
 import java.sql.SQLException;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/EncodeEntities.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/EncodeEntities.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/EncodeEntities.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/EncodeEntities.java Tue May 20 11:51:35 2008
@@ -14,9 +14,9 @@
 
 package org.example.app0.pages;
 
-import org.apache.tapestry.annotation.Property;
-import org.apache.tapestry.hibernate.annotations.CommitAfter;
-import org.apache.tapestry.ioc.annotation.Inject;
+import org.apache.tapestry5.annotations.Property;
+import org.apache.tapestry5.hibernate.annotations.CommitAfter;
+import org.apache.tapestry5.ioc.annotations.Inject;
 import org.example.app0.entities.User;
 import org.hibernate.Session;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/PersistEntity.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/PersistEntity.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/PersistEntity.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/PersistEntity.java Tue May 20 11:51:35 2008
@@ -14,10 +14,10 @@
 
 package org.example.app0.pages;
 
-import org.apache.tapestry.annotation.Persist;
-import org.apache.tapestry.annotation.Property;
-import org.apache.tapestry.hibernate.HibernateSessionManager;
-import org.apache.tapestry.ioc.annotation.Inject;
+import org.apache.tapestry5.annotations.Persist;
+import org.apache.tapestry5.annotations.Property;
+import org.apache.tapestry5.hibernate.HibernateSessionManager;
+import org.apache.tapestry5.ioc.annotations.Inject;
 import org.example.app0.entities.User;
 import org.example.app0.services.UserDAO;
 import org.hibernate.Session;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/Start.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/Start.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/Start.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/Start.java Tue May 20 11:51:35 2008
@@ -14,8 +14,8 @@
 
 package org.example.app0.pages;
 
-import org.apache.tapestry.annotation.InjectPage;
-import org.apache.tapestry.ioc.annotation.Inject;
+import org.apache.tapestry5.annotations.InjectPage;
+import org.apache.tapestry5.ioc.annotations.Inject;
 import org.example.app0.entities.User;
 import org.example.app0.services.UserDAO;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/services/AppModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/services/AppModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/services/AppModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/services/AppModule.java Tue May 20 11:51:35 2008
@@ -14,13 +14,13 @@
 
 package org.example.app0.services;
 
-import org.apache.tapestry.SymbolConstants;
-import org.apache.tapestry.hibernate.HibernateModule;
-import org.apache.tapestry.hibernate.HibernateTransactionDecorator;
-import org.apache.tapestry.ioc.MappedConfiguration;
-import org.apache.tapestry.ioc.ServiceBinder;
-import org.apache.tapestry.ioc.annotation.Match;
-import org.apache.tapestry.ioc.annotation.SubModule;
+import org.apache.tapestry5.SymbolConstants;
+import org.apache.tapestry5.hibernate.HibernateModule;
+import org.apache.tapestry5.hibernate.HibernateTransactionDecorator;
+import org.apache.tapestry5.ioc.MappedConfiguration;
+import org.apache.tapestry5.ioc.ServiceBinder;
+import org.apache.tapestry5.ioc.annotations.Match;
+import org.apache.tapestry5.ioc.annotations.SubModule;
 
 @SubModule(HibernateModule.class)
 public class AppModule

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/services/UserDAO.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/services/UserDAO.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/services/UserDAO.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/services/UserDAO.java Tue May 20 11:51:35 2008
@@ -14,7 +14,7 @@
 
 package org.example.app0.services;
 
-import org.apache.tapestry.hibernate.annotations.CommitAfter;
+import org.apache.tapestry5.hibernate.annotations.CommitAfter;
 import org.example.app0.entities.User;
 
 import java.util.List;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/resources/log4j.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/resources/log4j.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/resources/log4j.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/resources/log4j.properties Tue May 20 11:51:35 2008
@@ -21,7 +21,7 @@
 log4j.appender.A1.layout=org.apache.log4j.PatternLayout
 log4j.appender.A1.layout.ConversionPattern=[%p] %c{1} %m%n
 
-log4j.category.org.apache.tapestry.TapestryFilter=info
+log4j.category.org.apache.tapestry5.TapestryFilter=info
 log4j.category.org.apache.tapestry=error
 log4j.category.tapestry=error
 log4j.category.tapestry.ioc.ClassFactory=error

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/webapp/WEB-INF/web.xml
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/webapp/WEB-INF/web.xml?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/webapp/WEB-INF/web.xml (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/webapp/WEB-INF/web.xml Tue May 20 11:51:35 2008
@@ -26,7 +26,7 @@
     </context-param>
     <filter>
         <filter-name>app</filter-name>
-        <filter-class>org.apache.tapestry.TapestryFilter</filter-class>
+        <filter-class>org.apache.tapestry5.TapestryFilter</filter-class>
     </filter>
     <filter-mapping>
         <filter-name>app</filter-name>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/AnnotationProvider.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/AnnotationProvider.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/AnnotationProvider.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/AnnotationProvider.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 import java.lang.annotation.Annotation;
 
 /**
- * A source of annotations. This interface is used to mask where the annotations come from (for
- * example, from a Method, a Class, or some other source).
+ * A source of annotations. This interface is used to mask where the annotations come from (for example, from a Method,
+ * a Class, or some other source).
  */
 public interface AnnotationProvider
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/BaseLocatable.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/BaseLocatable.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Configuration.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Configuration.java Tue May 20 11:51:35 2008
@@ -1,35 +1,31 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc;
 
 /**
- * Object passed into a service contributor method that allows the method provide contributed values
- * to the service's configuration.
+ * Object passed into a service contributor method that allows the method provide contributed values to the service's
+ * configuration.
  * <p/>
- * A service can <em>collect</em> contributions in three different ways:
- * <ul>
- * <li>As an un-ordered collection of values</li>
- * <li>As an ordered list of values (where each value has a unique id, pre-requisited and
- * post-requisites)</li>
- * <li>As a map of keys and values
- * </ul>
+ * A service can <em>collect</em> contributions in three different ways: <ul> <li>As an un-ordered collection of
+ * values</li> <li>As an ordered list of values (where each value has a unique id, pre-requisited and
+ * post-requisites)</li> <li>As a map of keys and values </ul>
  * <p/>
  * This implementation is used for un-ordered configuration data.
  * <p/>
- * The service defines the <em>type</em> of contribution, in terms of a base class or service
- * interface. Contributions must be compatible with the type.
+ * The service defines the <em>type</em> of contribution, in terms of a base class or service interface. Contributions
+ * must be compatible with the type.
  */
 public interface Configuration<T>
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/IOCConstants.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/IOCConstants.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/IOCConstants.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/IOCConstants.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 public class IOCConstants
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/IOCUtilities.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/IOCUtilities.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/IOCUtilities.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/IOCUtilities.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import static org.apache.tapestry.ioc.IOCConstants.MODULE_BUILDER_MANIFEST_ENTRY_NAME;
-import org.apache.tapestry.ioc.annotation.SubModule;
+import static org.apache.tapestry5.ioc.IOCConstants.MODULE_BUILDER_MANIFEST_ENTRY_NAME;
+import org.apache.tapestry5.ioc.annotations.SubModule;
 
 import java.io.Closeable;
 import java.io.IOException;
@@ -26,7 +26,7 @@
 
 /**
  * A collection of utility methods for a couple of different areas, including creating the initial {@link
- * org.apache.tapestry.ioc.Registry}.
+ * org.apache.tapestry5.ioc.Registry}.
  */
 public final class IOCUtilities
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/IdMatcher.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/IdMatcher.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/IdMatcher.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/IdMatcher.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
  * A matcher of <em>fully qualified<em> ids.
@@ -26,4 +26,4 @@
      * @return true on match, false otherwise
      */
     boolean matches(String id);
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Invocation.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Invocation.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Locatable.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Locatable.java Tue May 20 11:51:35 2008
@@ -1,22 +1,21 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc;
 
 /**
- * Interface implemented by objects which carry a location tag. Defines a readable property,
- * location.
+ * Interface implemented by objects which carry a location tag. Defines a readable property, location.
  */
 public interface Locatable
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Location.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Location.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Location.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Location.java Tue May 20 11:51:35 2008
@@ -1,24 +1,23 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc;
 
 /**
- * A kind of tag applied to other objects to identify where they came from, in terms of a file (the
- * resource), a line number, and a column number. This is part of "line precise exception
- * reporting", whereby errors at runtime can be tracked backwards to the files from which they were
- * parsed or otherwise constructed.
+ * A kind of tag applied to other objects to identify where they came from, in terms of a file (the resource), a line
+ * number, and a column number. This is part of "line precise exception reporting", whereby errors at runtime can be
+ * tracked backwards to the files from which they were parsed or otherwise constructed.
  */
 public interface Location
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/LoggerSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/LoggerSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/LoggerSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/LoggerSource.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 import org.slf4j.Logger;
 
 /**
- * A wrapper around SLF4J's LoggerFactory that exists to allow particular projects to "hook" the
- * creation of Logger instances.
+ * A wrapper around SLF4J's LoggerFactory that exists to allow particular projects to "hook" the creation of Logger
+ * instances.
  */
 public interface LoggerSource
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/MappedConfiguration.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/MappedConfiguration.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/MappedConfiguration.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/MappedConfiguration.java Tue May 20 11:51:35 2008
@@ -1,33 +1,29 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc;
 
 /**
- * Object passed into a service contributor method that allows the method provide contributed values
- * to the service's configuration.
+ * Object passed into a service contributor method that allows the method provide contributed values to the service's
+ * configuration.
  * <p/>
- * A service can <em>collect</em> contributions in three different ways:
- * <ul>
- * <li>As an un-ordered collection of values</li>
- * <li>As an ordered list of values (where each value has a unique id, pre-requisited and
- * post-requisites)</li>
- * <li>As a map of keys and values
- * </ul>
+ * A service can <em>collect</em> contributions in three different ways: <ul> <li>As an un-ordered collection of
+ * values</li> <li>As an ordered list of values (where each value has a unique id, pre-requisited and
+ * post-requisites)</li> <li>As a map of keys and values </ul>
  * <p/>
- * The service defines the <em>type</em> of contribution, in terms of a base class or service
- * interface. Contributions must be compatible with the type.
+ * The service defines the <em>type</em> of contribution, in terms of a base class or service interface. Contributions
+ * must be compatible with the type.
  */
 public interface MappedConfiguration<K, V>
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/MessageFormatter.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/MessageFormatter.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Messages.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Messages.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
- * Provides access to a messages catalog, a set of properties files that provide localized messages
- * for a particular locale. The message catalog consists of keys and values and follows the
- * semantics of a Java {@link java.util.ResourceBundle} with some changes.
+ * Provides access to a messages catalog, a set of properties files that provide localized messages for a particular
+ * locale. The message catalog consists of keys and values and follows the semantics of a Java {@link
+ * java.util.ResourceBundle} with some changes.
  */
 public interface Messages
 {
@@ -27,8 +27,8 @@
     boolean contains(String key);
 
     /**
-     * Returns the localized message for the given key. If catalog does not contain such a key, then
-     * a modified version of the key is returned (converted to upper case and enclosed in brackets).
+     * Returns the localized message for the given key. If catalog does not contain such a key, then a modified version
+     * of the key is returned (converted to upper case and enclosed in brackets).
      *
      * @param key
      * @return localized message for key, or placeholder
@@ -36,8 +36,8 @@
     String get(String key);
 
     /**
-     * Returns a formatter for the message, which can be used to substitute arguments (as per
-     * {@link java.util.Formatter}).
+     * Returns a formatter for the message, which can be used to substitute arguments (as per {@link
+     * java.util.Formatter}).
      *
      * @param key
      * @return formattable object

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/MethodAdvice.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/MethodAdvice.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ModuleBuilderSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ModuleBuilderSource.java Tue May 20 11:51:35 2008
@@ -1,26 +1,25 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc;
 
 /**
- * The source for the module builder instance needed by most (but not all) service builders, service
- * contributors and service decorators. Allows the creation of the moduleBuilder instance to be
- * deferred until actually needed; in practical terms, when the builder/decorator/contributor is a
- * <em>static</em> method on the module builder class, then a module builder instance is not
- * needed. This allows Tapestry IOC to work around a tricky chicken-and-the-egg problem, whereby the
- * constructor of a module builder instance requires contributions that originate in the same
+ * The source for the module builder instance needed by most (but not all) service builders, service contributors and
+ * service decorators. Allows the creation of the moduleBuilder instance to be deferred until actually needed; in
+ * practical terms, when the builder/decorator/contributor is a <em>static</em> method on the module builder class, then
+ * a module builder instance is not needed. This allows Tapestry IOC to work around a tricky chicken-and-the-egg
+ * problem, whereby the constructor of a module builder instance requires contributions that originate in the same
  * module.
  */
 public interface ModuleBuilderSource

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ObjectCreator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ObjectCreator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ObjectCreator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ObjectCreator.java Tue May 20 11:51:35 2008
@@ -12,17 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
- * Interface used to encapsulate any strategy used defer the creation of some object until just as
- * needed.
+ * Interface used to encapsulate any strategy used defer the creation of some object until just as needed.
  */
 public interface ObjectCreator
 {
     /**
-     * Create and return the object.  In some limited circumstances, the implementation may cache
-     * the result, returning the same object for repeated calls.
+     * Create and return the object.  In some limited circumstances, the implementation may cache the result, returning
+     * the same object for repeated calls.
      */
     Object createObject();
 }

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ObjectLocator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ObjectLocator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Orderable.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Orderable.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.internal.util.Defense;
+import org.apache.tapestry5.ioc.internal.util.Defense;
 
 /**
  * A wrapper that allows objects of a target type to be ordered. Each Orderable object is given a unique id and a set of

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/OrderedConfiguration.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/OrderedConfiguration.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/OrderedConfiguration.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/OrderedConfiguration.java Tue May 20 11:51:35 2008
@@ -1,43 +1,38 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc;
 
 /**
- * Object passed into a service contributor method that allows the method provide contributed values
- * to the service's configuration.
+ * Object passed into a service contributor method that allows the method provide contributed values to the service's
+ * configuration.
  * <p/>
- * A service can <em>collect</em> contributions in three different ways:
- * <ul>
- * <li>As an un-ordered collection of values</li>
- * <li>As an ordered list of values (where each value has a unique id, pre-requisited and
- * post-requisites)</li>
- * <li>As a map of keys and values
- * </ul>
+ * A service can <em>collect</em> contributions in three different ways: <ul> <li>As an un-ordered collection of
+ * values</li> <li>As an ordered list of values (where each value has a unique id, pre-requisited and
+ * post-requisites)</li> <li>As a map of keys and values </ul>
  * <p/>
- * The service defines the <em>type</em> of contribution, in terms of a base class or service
- * interface. Contributions must be compatible with the type.
+ * The service defines the <em>type</em> of contribution, in terms of a base class or service interface. Contributions
+ * must be compatible with the type.
  */
 public interface OrderedConfiguration<T>
 {
     /**
-     * Adds an ordered object to a service's contribution. Each object has an id (which must be
-     * unique). Optionally, pre-requisites (a list of ids that must precede this object) and
-     * post-requisites (ids that must follow) can be provided.
+     * Adds an ordered object to a service's contribution. Each object has an id (which must be unique). Optionally,
+     * pre-requisites (a list of ids that must precede this object) and post-requisites (ids that must follow) can be
+     * provided.
      *
-     * @param id          a unique id for the object; the id will be fully qualified with the contributing
-     *                    module's id
+     * @param id          a unique id for the object; the id will be fully qualified with the contributing module's id
      * @param constraints used to order the object relative to other contributed objects
      * @parm object to add to the service's configuration
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Registry.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Registry.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Registry.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Registry.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.EagerLoad;
+import org.apache.tapestry5.ioc.annotations.EagerLoad;
 
 /**
  * Public access to the IoC service registry.
@@ -25,8 +25,8 @@
      * Invoked at the end of a request to discard any thread-specific information accumulated during the current
      * request.
      *
-     * @see org.apache.tapestry.ioc.services.PerthreadManager
-     * @see org.apache.tapestry.ioc.services.ThreadCleanupListener
+     * @see org.apache.tapestry5.ioc.services.PerthreadManager
+     * @see org.apache.tapestry5.ioc.services.ThreadCleanupListener
      */
     void cleanupThread();
 
@@ -34,8 +34,8 @@
      * Shuts down a Registry instance. Notifies all listeners that the registry has shutdown. Further method invocations
      * on the Registry are no longer allowed, and the Registry instance should be discarded.
      *
-     * @see org.apache.tapestry.ioc.services.RegistryShutdownHub
-     * @see org.apache.tapestry.ioc.services.RegistryShutdownListener
+     * @see org.apache.tapestry5.ioc.services.RegistryShutdownHub
+     * @see org.apache.tapestry5.ioc.services.RegistryShutdownListener
      */
     void shutdown();
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/RegistryBuilder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/RegistryBuilder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Resource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Resource.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 import java.io.IOException;
 import java.io.InputStream;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceBinder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceBinder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceBinder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ServiceBinder.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.Scope;
-import org.apache.tapestry.ioc.def.ServiceDef;
+import org.apache.tapestry5.ioc.annotations.Scope;
+import org.apache.tapestry5.ioc.def.ServiceDef;
 
 /**
  * Allows a module to bind service interfaces to service implementation classes in support of autobuilding services. A
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/SampleEntity.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/apache/tapestry5/internal/hibernate/SampleEntity.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.internal.hibernate;
+package org.apache.tapestry5.internal.hibernate;
 
 import javax.persistence.Entity;
 import javax.persistence.Id;
 
 /**
  * Fake entity used by {@link org.apache.tapestry.internal.hibernate.HibernateEntityValueEncoderTest}.
  */
 @Entity
 public class SampleEntity
@@ -12,13 +12,13 @@
 
 /**
- * Fake entity used by {@link org.apache.tapestry.internal.hibernate.HibernateEntityValueEncoderTest}.
+ * Fake entity used by {@link org.apache.tapestry5.internal.hibernate.HibernateEntityValueEncoderTest}.
  */
 @Entity

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/CachedForm.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-hibernate/src/test/java/org/example/app0/pages/CachedForm.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/BaseLocatable.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/BaseLocatable.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
  * Base implementation of {@link org.apache.tapestry.ioc.Locatable}.
  */
 public class BaseLocatable implements Locatable
 {
@@ -12,10 +12,10 @@
 
 /**
- * Base implementation of {@link org.apache.tapestry.ioc.Locatable}.
+ * Base implementation of {@link org.apache.tapestry5.ioc.Locatable}.
  */
 public class BaseLocatable implements Locatable

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Configuration.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Configuration.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Invocation.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Invocation.java Tue May 20 11:51:35 2008
@@ -12,10 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
  * A method invocation passed to an {@link org.apache.tapestry.ioc.MethodAdvice}.
  */
 public interface Invocation
 {
@@ -12,10 +12,10 @@
 
 /**
- * A method invocation passed to an {@link org.apache.tapestry.ioc.MethodAdvice}.
+ * A method invocation passed to an {@link org.apache.tapestry5.ioc.MethodAdvice}.
  */
 public interface Invocation

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Locatable.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Locatable.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/MessageFormatter.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/MessageFormatter.java Tue May 20 11:51:35 2008
@@ -1,29 +1,29 @@
-// Copyright 2006 The Apache Software Foundation
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-//     http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-package org.apache.tapestry.ioc;
+// Copyright 2006 The Apache Software Foundation
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+//     http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+package org.apache.tapestry5.ioc;
 
 /**
  * Obtained from a {@link org.apache.tapestry.ioc.Messages}, used to format messages for a specific
  * localized message key.
  */
 public interface MessageFormatter
 {
     /**
-     * Formats the message. The arguments are passed to {@link java.util.Formatter} as is with one
-     * exception: Object of type {@link Throwable} are converted to their
-     * {@link Throwable#getMessage()} (or, if that is null, to the name of the class).
+     * Formats the message. The arguments are passed to {@link java.util.Formatter} as is with one exception: Object of
+     * type {@link Throwable} are converted to their {@link Throwable#getMessage()} (or, if that is null, to the name of
+     * the class).
      *
      * @param args
      * @return formatted string
@@ -1,29 +1,29 @@
 
 /**
- * Obtained from a {@link org.apache.tapestry.ioc.Messages}, used to format messages for a specific
- * localized message key.
+ * Obtained from a {@link org.apache.tapestry5.ioc.Messages}, used to format messages for a specific localized message
+ * key.
  */
 public interface MessageFormatter

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Messages.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Messages.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/MethodAdvice.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/MethodAdvice.java Tue May 20 11:51:35 2008
@@ -12,20 +12,20 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
  * For Tapestry IoC, Aspects provide a limited amount of advise, i.e., advising method invocations. That's the only join
  * point available (method invocations of service interface methods); full AOP systems such as AspectJ can do much, much
  * such as advising field access and even object construction.
  *
- * @see org.apache.tapestry.ioc.services.AspectDecorator
+ * @see org.apache.tapestry5.ioc.services.AspectDecorator
  */
 public interface MethodAdvice
 {
     /**
      * Allows the Aspect to advise the invocation.  The Aspect is free to inspect and even replace parameters. Most
      * Aspects will then invoke {@link org.apache.tapestry.ioc.Invocation#proceed()}.  The Aspect may then inspect and
      * replace any checked thrown exceptions. Some Aspects (for example, caching) may selectively decide to bypass the
      * invocation entirely, and instead invoke some other method or otherwise set a return value or thrown exception.
      *
@@ -12,20 +12,20 @@
     /**
      * Allows the Aspect to advise the invocation.  The Aspect is free to inspect and even replace parameters. Most
-     * Aspects will then invoke {@link org.apache.tapestry.ioc.Invocation#proceed()}.  The Aspect may then inspect and
+     * Aspects will then invoke {@link org.apache.tapestry5.ioc.Invocation#proceed()}.  The Aspect may then inspect and
      * replace any checked thrown exceptions. Some Aspects (for example, caching) may selectively decide to bypass the
      * invocation entirely, and instead invoke some other method or otherwise set a return value or thrown exception.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ModuleBuilderSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ModuleBuilderSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ObjectLocator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ObjectLocator.java Tue May 20 11:51:35 2008
@@ -12,15 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.services.MasterObjectProvider;
+import org.apache.tapestry5.ioc.services.MasterObjectProvider;
 
 /**
  * Defines an object which can provide access to services defined within a {@link org.apache.tapestry.ioc.Registry}, or
  * to objects or object instances available by other means. Services are accessed via service id, or (when appropriate)
  * by just service interface. The Registry itself implements this interface, as does {@link
- * org.apache.tapestry.ioc.ServiceResources}.
+ * org.apache.tapestry5.ioc.ServiceResources}.
  */
 public interface ObjectLocator
 {
@@ -54,8 +54,8 @@
     <T> T getService(Class<T> serviceInterface);
 
     /**
      * Obtains an object indirectly, using an {@link org.apache.tapestry.ioc.ObjectProvider} identified by the prefix of
      * the reference.
      *
      * @param objectType         the type of object to be returned
      * @param annotationProvider provides access to annotations on the field or parameter for which a value is to be
@@ -84,7 +84,7 @@
      * Creates a proxy. The proxy will defer invocation of {@link #autobuild(Class)} until just-in-time (that is, first
      * method invocation). In a limited number of cases, it is necessary to use such a proxy to prevent service
      * construction cycles, particularly when contributing (directly or indirectly) to the {@link
      * org.apache.tapestry.ioc.services.MasterObjectProvider} (which is itself at the heart of autobuilding).
      *
      * @param <T>
      * @param interfaceClass      the interface implemented by the proxy
@@ -92,4 +92,4 @@
      * @return a proxy
      */
     <T> T proxy(Class<T> interfaceClass, Class<? extends T> implementationClass);
-}
\ No newline at end of file
+}
@@ -12,15 +12,15 @@
 
 /**
- * Defines an object which can provide access to services defined within a {@link org.apache.tapestry.ioc.Registry}, or
+ * Defines an object which can provide access to services defined within a {@link org.apache.tapestry5.ioc.Registry}, or
  * to objects or object instances available by other means. Services are accessed via service id, or (when appropriate)
  * by just service interface. The Registry itself implements this interface, as does {@link
@@ -54,8 +54,8 @@
 
     /**
-     * Obtains an object indirectly, using an {@link org.apache.tapestry.ioc.ObjectProvider} identified by the prefix of
-     * the reference.
+     * Obtains an object indirectly, using an {@link org.apache.tapestry5.ioc.ObjectProvider} identified by the prefix
+     * of the reference.
      *
      * @param objectType         the type of object to be returned
@@ -84,7 +84,7 @@
      * method invocation). In a limited number of cases, it is necessary to use such a proxy to prevent service
      * construction cycles, particularly when contributing (directly or indirectly) to the {@link
-     * org.apache.tapestry.ioc.services.MasterObjectProvider} (which is itself at the heart of autobuilding).
+     * org.apache.tapestry5.ioc.services.MasterObjectProvider} (which is itself at the heart of autobuilding).
      *
      * @param <T>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ObjectProvider.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ObjectProvider.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ObjectProvider.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/ObjectProvider.java Tue May 20 11:51:35 2008
@@ -12,31 +12,30 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
 /**
  * Object providers represent an alternate way to locate an object provided somewhere in the
  * {@link org.apache.tapestry.ioc.Registry}. Instead of using a just the service id to gain access
  * to a service within the Registry, object providers in different flavors are capable of vending,
  * or even creating, objects of disparate types from disparate sources.
  * <p/>
  * Object providers are consulted in a strict order, and the first non-null result is taken.
  * <p/>
- * In many cases, an object provider searches for additional annotations on the element (usually a
- * parameter, or perhaps a field) for which a value is required.
+ * In many cases, an object provider searches for additional annotations on the element (usually a parameter, or perhaps
+ * a field) for which a value is required.
  */
 public interface ObjectProvider
 {
     /**
-     * Provides an object based on an expression. The process of providing objects occurs within a
-     * particular <em>context</em>, which will typically be a service builder method, service
-     * contributor method, or service decorator method. The locator parameter provides access to the
-     * services visible <em>to that context</em>.
+     * Provides an object based on an expression. The process of providing objects occurs within a particular
+     * <em>context</em>, which will typically be a service builder method, service contributor method, or service
+     * decorator method. The locator parameter provides access to the services visible <em>to that context</em>.
      *
      * @param objectType         the expected object type
      * @param annotationProvider provides access to annotations (typically, the field or parameter to which an
-     *                           injection-related annotation is attached); annotations on the field or parameter
-     *                           may also be used when resolving the desired object
+     *                           injection-related annotation is attached); annotations on the field or parameter may
+     *                           also be used when resolving the desired object
      * @param locator            locator for the <em>context</em> in which the provider is being used
      * @param <T>
      * @return the requested object, or null if this object provider can not supply an object
@@ -12,31 +12,30 @@
 
 /**
- * Object providers represent an alternate way to locate an object provided somewhere in the
- * {@link org.apache.tapestry.ioc.Registry}. Instead of using a just the service id to gain access
- * to a service within the Registry, object providers in different flavors are capable of vending,
- * or even creating, objects of disparate types from disparate sources.
+ * Object providers represent an alternate way to locate an object provided somewhere in the {@link
+ * org.apache.tapestry5.ioc.Registry}. Instead of using a just the service id to gain access to a service within the
+ * Registry, object providers in different flavors are capable of vending, or even creating, objects of disparate types
+ * from disparate sources.
  * <p/>
  * Object providers are consulted in a strict order, and the first non-null result is taken.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Orderable.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Orderable.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/RegistryBuilder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/RegistryBuilder.java Tue May 20 11:51:35 2008
@@ -12,19 +12,19 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.ioc;
+package org.apache.tapestry5.ioc;
 
-import org.apache.tapestry.ioc.annotation.SubModule;
-import org.apache.tapestry.ioc.def.ModuleDef;
-import org.apache.tapestry.ioc.internal.DefaultModuleDefImpl;
-import org.apache.tapestry.ioc.internal.LoggerSourceImpl;
-import org.apache.tapestry.ioc.internal.RegistryImpl;
-import org.apache.tapestry.ioc.internal.RegistryWrapper;
-import org.apache.tapestry.ioc.internal.services.ClassFactoryImpl;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import org.apache.tapestry.ioc.internal.util.OneShotLock;
-import org.apache.tapestry.ioc.services.ClassFactory;
-import org.apache.tapestry.ioc.services.TapestryIOCModule;
+import org.apache.tapestry5.ioc.annotations.SubModule;
+import org.apache.tapestry5.ioc.def.ModuleDef;
+import org.apache.tapestry5.ioc.internal.DefaultModuleDefImpl;
+import org.apache.tapestry5.ioc.internal.LoggerSourceImpl;
+import org.apache.tapestry5.ioc.internal.RegistryImpl;
+import org.apache.tapestry5.ioc.internal.RegistryWrapper;
+import org.apache.tapestry5.ioc.internal.services.ClassFactoryImpl;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.OneShotLock;
+import org.apache.tapestry5.ioc.services.ClassFactory;
+import org.apache.tapestry5.ioc.services.TapestryIOCModule;
 import org.slf4j.Logger;
 
 import java.lang.reflect.AnnotatedElement;
@@ -33,7 +33,7 @@
 import java.util.Set;
 
 /**
  * Used to construct the IoC {@link org.apache.tapestry.ioc.Registry}. This class is <em>not</em> thread-safe. The
  * Registry, once created, <em>is</em> thread-safe.
  */
 public final class RegistryBuilder
@@ -100,7 +100,7 @@
     /**
      * Adds a number of modules (as module classes) to the registry, returning the builder for further configuration.
      *
-     * @see org.apache.tapestry.ioc.annotation.SubModule
+     * @see org.apache.tapestry5.ioc.annotations.SubModule
      */
     public RegistryBuilder add(Class... moduleBuilderClasses)
     {
@@ -135,7 +135,7 @@
      * Adds a number of module classes (specified by fully qualified class name) to the registry, returning the builder
      * for further configuration.
      *
-     * @see org.apache.tapestry.ioc.annotation.SubModule
+     * @see org.apache.tapestry5.ioc.annotations.SubModule
      */
     public RegistryBuilder add(String classname)
     {
@@ -157,7 +157,7 @@
 
     /**
      * Constructs and returns the registry; this may only be done once. The caller is responsible for invoking {@link
-     * org.apache.tapestry.ioc.Registry#performRegistryStartup()}.
+     * org.apache.tapestry5.ioc.Registry#performRegistryStartup()}.
      */
     public Registry build()
     {
@@ -33,7 +33,7 @@
 
 /**
- * Used to construct the IoC {@link org.apache.tapestry.ioc.Registry}. This class is <em>not</em> thread-safe. The
+ * Used to construct the IoC {@link org.apache.tapestry5.ioc.Registry}. This class is <em>not</em> thread-safe. The
  * Registry, once created, <em>is</em> thread-safe.
  */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Resource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-ioc/src/main/java/org/apache/tapestry5/ioc/Resource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================